# OpenMBEE Python Library

This python module providers client wrappers and utilities for interacting with the following OpenMBEE tools/technologies:
 - Confluence
 - IncQuery
 - SPARQL

## [See the full API documentation here](https://opl.readthedocs.io/en/latest/apidocs/opl.html#module-opl)

